/*
 * Copyright (c) 2004, Stefan Walter
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *     * Redistributions of source code must retain the above 
 *       copyright notice, this list of conditions and the 
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the 
 *       above copyright notice, this list of conditions and 
 *       the following disclaimer in the documentation and/or 
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be 
 *       used to endorse or promote products derived from this 
 *       software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 * 
 *
 * CONTRIBUTORS
 *  Stef Walter <stef@memberwebs.com>
 *
 */ 

#include <sys/types.h>
#include <sys/param.h>
#include <sys/jail.h>

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "util.h"

#ifdef HAVE_CONFIG_H
#include "../config.h"
#endif

static void usage();

int main(int argc, char* argv[])
{
	struct xprison* xp = NULL;
	size_t len;
	jails jls;
	char* e;
	
	/* Remove the program name */
	argc--;
	argv++;
	
	if(argc != 1)
		usage();
		
	if(running_in_jail() != 0)
		errx(1, "can't run from inside jail");

	jails_load(&jls);
	xp = jails_find(&jls, argv[0]);

	strtol(argv[0], &e, 10);
	
	/* If it was all a number ... */
	if(!*e)
	{
		if(xp == NULL)
			errx(1, "unknown jail id: %s", argv[0]);

		printf("%s\n", xp->pr_host);
	}
	
	/* otherwise it's a host name */
	else
	{
		if(xp == NULL)
			errx(1, "unknown jail host name: %s", argv[0]);

		printf("%d\n", xp->pr_id);
	}

	jails_done(&jls);

	return 0;
}

static void usage()
{
	fprintf(stderr, "usage: jid hostname \n");
	exit(2);
}	

